==> OneSignal-2.6.0-sources.jar: com/onesignal/OSNotificationPayload.java <==
/**
 * Modified MIT License
 *
 * Copyright 2016 OneSignal
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * 1. The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * 2. All copies of substantial portions of the Software may only be used in connection
 * with services provided by OneSignal.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package com.onesignal;

import org.json.JSONObject;

import java.util.List;

// Notification properties received from OneSignal.
public class OSNotificationPayload {
   public String notificationId;
   public String title, message;
   public JSONObject additionalData;
   public String smallIcon;
   public String bigPicture;
   public String largeIcon;
   public String launchUrl;
   public String sound;
   public String group;
   public String backgroundColor;
   public String ledColor;
   public int visibility;
   public String groupMessage;
   public List<ActionButton> actionButtons;
   public boolean backgroundData;
   public String fromProjectNumber;
   public boolean restoring;
   public BackgroundImageLayout backgroundImageLayout;
   
   public static class ActionButton {
      public String id;
      public String text;
      public String icon;
   }

   public static class BackgroundImageLayout {
      public String image;
      public String titleTextColor;
      public String bodyTextColor;
   }
}

==> OneSignal-3.0.4-rc2-sources.jar: com/onesignal/OSNotificationPayload.java <==
/**
 * Modified MIT License
 *
 * Copyright 2016 OneSignal
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * 1. The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * 2. All copies of substantial portions of the Software may only be used in connection
 * with services provided by OneSignal.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package com.onesignal;

import org.json.JSONObject;

import java.util.List;

// Notification properties received from OneSignal.
public class OSNotificationPayload {
   public String notificationId;
   public String title, body;
   public JSONObject additionalData;
   public String smallIcon;
   public String largeIcon;
   public String bigPicture;
   public String smallIconAccentColor;
   public String launchUrl;
   public String sound;
   public String ledColor;
   public int lockScreenVisibility = 1;
   public String groupKey;
   public String groupMessage;
   public List<ActionButton> actionButtons;
   public String fromProjectNumber;
   public BackgroundImageLayout backgroundImageLayout;
   public String rawPayload;
   
   public static class ActionButton {
      public String id;
      public String text;
      public String icon;
   }

   public static class BackgroundImageLayout {
      public String image;
      public String titleTextColor;
      public String bodyTextColor;
   }
}
